@@ -21,8 +21,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#pragma interface
-
 #include <tagcoll/Serializer.h>
 #include "Tag.h"
 
@@ -30,56 +28,30 @@ namespace Tagcoll
 {
 
 /**
- * Serialize Tags to and from Strings
+ * Convert Tags into strings
  */
 template<>
-class Serializer<std::string, Tag>
+class Converter<Tag, std::string>
+{
+public:
+	std::string operator()(const Tag& item);
+	OpSet<std::string> operator()(const OpSet<Tag>& items);
+};
+
+/**
+ * Convert strings into tags
+ */
+template<>
+class Converter<std::string, Tag>
 {
 protected:
 	FacetSet& _voc;
 
 public:
-	Serializer(FacetSet& voc) throw () : _voc(voc) {}
+	Converter(FacetSet& voc) : _voc(voc) {}
 
-	/**
-	 * Convert a TAG to a string
-	 */
-	std::string tagToString(const Tag& tag) throw ();
-
-	/**
-	 * Convert an ITEM to a string
-	 */
-	std::string itemToString(const std::string& item) throw () { return item; }
-
-	/**
-	 * Convert a string to a TAG
-	 */
-	Tag stringToTag(const std::string& tag) throw ();
-
-	/**
-	 * Convert a string to an ITEM
-	 */
-	std::string stringToItem(const std::string& item) throw () { return item; }
-
-	/**
-	 * Convert TAGs to strings
-	 */
-	OpSet<std::string> tagsToStrings(const OpSet<Tag>& tag) throw ();
-
-	/**
-	 * Convert ITEMs to strings
-	 */
-	OpSet<std::string> itemsToStrings(const OpSet<std::string>& items) throw () { return items; }
-
-	/**
-	 * Convert strings to TAGs
-	 */
-	OpSet<Tag> stringsToTags(const OpSet<std::string>& tags) throw ();
-
-	/**
-	 * Convert strings to ITEMs
-	 */
-	OpSet<std::string> stringsToItems(const OpSet<std::string>& items) throw () { return items; }
+	Tag operator()(const std::string& item);
+	OpSet<Tag> operator()(const OpSet<std::string>& items);
 };
 
 };
