@@ -18,8 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#pragma implementation
-
 #include "TagSelector.h"
 #include "TagMenu.h"
 
@@ -126,7 +124,7 @@ void TagSelector::on_document_changed()
 	updateView();
 	time_t end = time(NULL);
 	if (end != start)
-		fprintf(stderr, "TagSelector::on_document_changed: %d seconds\n", (end-start));
+		fprintf(stderr, "TagSelector::on_document_changed: %ld seconds\n", (end-start));
 }
 
 TagSelector::TagSelector(TagcollDocument<std::string>& doc)
@@ -360,7 +358,7 @@ void TagSelector::updateView()
 
 	time_t end = time(NULL);
 	if (end != start)
-		fprintf(stderr, "TagSelector::updateList: %d seconds\n", (end-start));
+		fprintf(stderr, "TagSelector::updateList: %ld seconds\n", (end-start));
 }
 
 // vim:set ts=4 sw=4:
