@@ -18,21 +18,17 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#pragma implementation
-
 #include "TagcollDocument.h"
 
-#include <tagcoll/FilterChain.h>
+#include <tagcoll/Filter.h>
 #include <tagcoll/Implications.h>
-#include <tagcoll/TagcollFilter.h>
 #include <tagcoll/DerivedTags.h> 
 #include <tagcoll/InputMerger.h>
 #include <tagcoll/ItemGrouper.h>
 #include <tagcoll/TextFormat.h>
-#include <tagcoll/ExpressionFilter.h>
+#include <tagcoll/Expression.h>
 #include <tagcoll/StdioParserInput.h>
 #include <tagcoll/StringParserInput.h>
-#include <tagcoll/SerializationFilters.h>
 
 #include "Environment.h"
 #include "Serializer.h"
@@ -42,9 +38,6 @@
 using namespace std;
 using namespace Tagcoll;
 
-template class TagcollDocument<std::string>;
-
-
 const char* fn_tagdb = "/var/lib/debtags/package-tags";
 const char* fn_impls = "/var/lib/debtags/implications";
 const char* fn_deriv = "/var/lib/debtags/derived-tags";
@@ -137,18 +130,18 @@ void TagcollDocument<T>::applyChange(const PatchList<T, Tag>& change)
 
 template<class T>
 void TagcollDocument<T>::load(const string& file)
-	throw (FileException, ParserException)
 {
-	Serializer<string, Tag> serializer(_facets);
+	Converter<string, T> toitems;
+	Converter<string, Tag> totags(_facets);
 	if (file == "-")
 	{
 		StdioParserInput in(stdin, "<stdin>");
-		TextFormat<T, Tag>::parse(in, serializer, _collection);
+		TextFormat<T, Tag>::parse(toitems, totags, in, _collection);
 	}
 	else
 	{
 		StdioParserInput in(file);
-		TextFormat<T, Tag>::parse(in, serializer, _collection);
+		TextFormat<T, Tag>::parse(toitems, totags, in, _collection);
 	}
 	_undoBuffer.clear();
 	_undoTail = 0;
@@ -160,24 +153,24 @@ void TagcollDocument<T>::load(const string& file)
 
 template<class T>
 void TagcollDocument<T>::loadDebtags()
-	throw (FileException, ParserException)
 {
 	load(fn_tagdb);
 }
 
 template<class T>
-void TagcollDocument<T>::save(const std::string& file) throw (FileException)
+void TagcollDocument<T>::save(const std::string& file)
 {
 	FILE* out = fopen(file.c_str(), "wt");
 	if (!out)
 		throw FileException(errno, "opening file " + file);
 
 	// Output the collection, grouping the items
-	Serializer<string, Tag> serializer(_facets);
+	Converter<T, string> fromitems;
+	Converter<Tag, string> fromtags;
 	ItemGrouper<T, Tag> grouper;
 	output(grouper);
 
-	TextFormat<T, Tag> writer(serializer, out);
+	TextFormat<T, Tag> writer(fromitems, fromtags, out);
 	grouper.output(writer);
 
 	fclose(out);
@@ -190,9 +183,11 @@ void TagcollDocument<T>::save(const std::string& file) throw (FileException)
 }
 
 template<class ITEM>
-void TagcollDocument<ITEM>::output(TagcollConsumer<ITEM, Tag>& consumer) throw ()
+void TagcollDocument<ITEM>::output(Consumer<ITEM, Tag>& consumer)
 {
 	collection().output(consumer);
 }
 
+template class TagcollDocument<std::string>;
+
 // vim:set ts=4 sw=4:
